@@ -17,8 +17,10 @@ assign("mosaic.options", list(), envir = .mosaicEnv)
   assign("original.lattice.options", origLatticeOptions, envir = .mosaicEnv)
   packageStartupMessage(
     paste0("\nThe 'mosaic' package masks several functions from core packages ",
-           "in order to add additional features.  ",
-           "\nThe original behavior of these functions should not be affected by this."),
+           "in order to add \nadditional features.  ",
+           "The original behavior of these functions should not be affected by this.",
+           "\n\nNote: If you use the Matrix package, be sure to load it BEFORE loading mosaic."
+           ),
     appendLF = TRUE)
 }
 
